#[repr(transparent)]pub struct ForceEvent(pub u32);Expand description
Force Event
Tuple Fields
0: u32Implementations
Sourceimpl ForceEvent
impl ForceEvent
Sourcepub const fn fevtac12ne(&self) -> bool
pub const fn fevtac12ne(&self) -> bool
Force event auto command 12 not executed
Sourcepub const fn set_fevtac12ne(&mut self, val: bool)
pub const fn set_fevtac12ne(&mut self, val: bool)
Force event auto command 12 not executed
Sourcepub const fn fevtac12toe(&self) -> bool
pub const fn fevtac12toe(&self) -> bool
Force event auto command 12 time out error
Sourcepub const fn set_fevtac12toe(&mut self, val: bool)
pub const fn set_fevtac12toe(&mut self, val: bool)
Force event auto command 12 time out error
Sourcepub const fn fevtac12ce(&self) -> bool
pub const fn fevtac12ce(&self) -> bool
Force event auto command 12 CRC error
Sourcepub const fn set_fevtac12ce(&mut self, val: bool)
pub const fn set_fevtac12ce(&mut self, val: bool)
Force event auto command 12 CRC error
Sourcepub const fn fevtac12ebe(&self) -> bool
pub const fn fevtac12ebe(&self) -> bool
Force event Auto Command 12 end bit error
Sourcepub const fn set_fevtac12ebe(&mut self, val: bool)
pub const fn set_fevtac12ebe(&mut self, val: bool)
Force event Auto Command 12 end bit error
Sourcepub const fn fevtac12ie(&self) -> bool
pub const fn fevtac12ie(&self) -> bool
Force event Auto Command 12 index error
Sourcepub const fn set_fevtac12ie(&mut self, val: bool)
pub const fn set_fevtac12ie(&mut self, val: bool)
Force event Auto Command 12 index error
Sourcepub const fn fevtcnibac12e(&self) -> bool
pub const fn fevtcnibac12e(&self) -> bool
Force event command not executed by Auto Command 12 error
Sourcepub const fn set_fevtcnibac12e(&mut self, val: bool)
pub const fn set_fevtcnibac12e(&mut self, val: bool)
Force event command not executed by Auto Command 12 error
Sourcepub const fn set_fevtctoe(&mut self, val: bool)
pub const fn set_fevtctoe(&mut self, val: bool)
Force event command time out error
Sourcepub const fn set_fevtcce(&mut self, val: bool)
pub const fn set_fevtcce(&mut self, val: bool)
Force event command CRC error
Sourcepub const fn set_fevtcebe(&mut self, val: bool)
pub const fn set_fevtcebe(&mut self, val: bool)
Force event command end bit error
Sourcepub const fn set_fevtcie(&mut self, val: bool)
pub const fn set_fevtcie(&mut self, val: bool)
Force event command index error
Sourcepub const fn set_fevtdtoe(&mut self, val: bool)
pub const fn set_fevtdtoe(&mut self, val: bool)
Force event data time out error
Sourcepub const fn set_fevtdce(&mut self, val: bool)
pub const fn set_fevtdce(&mut self, val: bool)
Force event data CRC error
Sourcepub const fn set_fevtdebe(&mut self, val: bool)
pub const fn set_fevtdebe(&mut self, val: bool)
Force event data end bit error
Sourcepub const fn set_fevtac12e(&mut self, val: bool)
pub const fn set_fevtac12e(&mut self, val: bool)
Force event Auto Command 12 error
Sourcepub const fn set_fevttne(&mut self, val: bool)
pub const fn set_fevttne(&mut self, val: bool)
Force tuning error
Sourcepub const fn set_fevtdmae(&mut self, val: bool)
pub const fn set_fevtdmae(&mut self, val: bool)
Force event DMA error
Sourcepub const fn set_fevtcint(&mut self, val: bool)
pub const fn set_fevtcint(&mut self, val: bool)
Force event card interrupt