nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

WtmkLvl

Struct WtmkLvl 

#[repr(transparent)]
pub struct WtmkLvl(pub u32);
Watermark Level

Tuple Fields

0: u32

Implementations

Source

impl WtmkLvl

pub const fn rd_wml(&self) -> u8

Read watermark level

pub const fn set_rd_wml(&mut self, val: u8)

Read watermark level

pub const fn rd_brst_len(&self) -> u8

Read burst length due to system restriction, the actual burst length might not exceed 16

pub const fn set_rd_brst_len(&mut self, val: u8)

Read burst length due to system restriction, the actual burst length might not exceed 16

pub const fn wr_wml(&self) -> u8

Write watermark level

pub const fn set_wr_wml(&mut self, val: u8)

Write watermark level

pub const fn wr_brst_len(&self) -> u8

Write burst length due to system restriction, the actual burst length might not exceed 16

pub const fn set_wr_brst_len(&mut self, val: u8)

Write burst length due to system restriction, the actual burst length might not exceed 16