#[repr(transparent)]pub struct WtmkLvl(pub u32);Expand description
Watermark Level
Tuple Fields
0: u32Implementations
Sourceimpl WtmkLvl
impl WtmkLvl
Sourcepub const fn set_rd_wml(&mut self, val: u8)
pub const fn set_rd_wml(&mut self, val: u8)
Read watermark level
Sourcepub const fn rd_brst_len(&self) -> u8
pub const fn rd_brst_len(&self) -> u8
Read burst length due to system restriction, the actual burst length might not exceed 16
Sourcepub const fn set_rd_brst_len(&mut self, val: u8)
pub const fn set_rd_brst_len(&mut self, val: u8)
Read burst length due to system restriction, the actual burst length might not exceed 16
Sourcepub const fn set_wr_wml(&mut self, val: u8)
pub const fn set_wr_wml(&mut self, val: u8)
Write watermark level
Sourcepub const fn wr_brst_len(&self) -> u8
pub const fn wr_brst_len(&self) -> u8
Write burst length due to system restriction, the actual burst length might not exceed 16
Sourcepub const fn set_wr_brst_len(&mut self, val: u8)
pub const fn set_wr_brst_len(&mut self, val: u8)
Write burst length due to system restriction, the actual burst length might not exceed 16